CCL: Globals

CCL

- ccl_angulo : ccl_config.h
- ccl_bbks : ccl_config.h
- ccl_boltzmann : ccl_config.h
- ccl_boltzmann_camb : ccl_config.h
- ccl_boltzmann_class : ccl_config.h
- ccl_eisenstein_hu : ccl_config.h
- ccl_emulator : ccl_config.h
- CCL_ERROR_POLICY_CONTINUE : ccl_error.h
- CCL_ERROR_POLICY_EXIT : ccl_error.h
- ccl_fitting_function : ccl_config.h
- ccl_halo_model : ccl_config.h
- ccl_halofit : ccl_config.h
- ccl_linear : ccl_config.h
- ccl_none : ccl_config.h
- ccl_omega_g_label : ccl_background.h
- ccl_omega_k_label : ccl_background.h
- ccl_omega_l_label : ccl_background.h
- ccl_omega_m_label : ccl_background.h
- ccl_omega_nu_label : ccl_background.h
- ccl_omega_ur_label : ccl_background.h
- ccl_tinker : ccl_config.h
- ccl_tinker10 : ccl_config.h
- ccl_watson : ccl_config.h